***************************************************************************************************
*Data: UKHLS Harmonized BHPS IN
*Data: Study Number 6931 
/*
Understanding Society: Waves 1-8, 2009-2017 and Harmonised BHPS: Waves 1-18, 1991-2009: Special Licence Access
*/

*Special license only because it contains the birth months of the individuals and their children
*1. Get Sample
*2. Get Key Variables Clarified
***************************************************************************************************
 clear
 set more off
 do "C:\Users\Muzhi\OneDrive - Nexus365\Research\GenderDivision_Fertility\Stata2019\Do_edt\equity0_dir"
 capture log close 
 log using "$Output\equity1_sample", replace //log file 
 
 set seed 13579 
  
*************************************************************
*A. Select BHPS and UnSoc
*************************************************************
use "$RawData\ukhls3_pooled",clear //harmonized data - cleaned, prepared with marital and childbirth info
	ta wave,m //612761 records from waves 1-26
	
	keep pidp pid wave ivfio doiy doim  intd_cu intd_pre ///
		 x_strata x_psu sppid_bh sppid new_hid ///
		 howlng n_husits n_husits2  ///
		 sex  x_birthy age ///
		 nchild chagemin new_mastat par_dur  parbgyr   ///
		 edu3c x_race religion_dum  new_hlstat country ///
		 scopfam* gender_liberal4f gender_liberal3f ///
		 workhrall jbstat jbstat_new employed new_jbft ///
		 fimngrs_dv fimngrs15 fihhmn_all15 lnfimnlabgrs lnfimngrs lnfimnnet lnfihhmn ///
		 hh_xhweight  xweight lrwght lrwt* *_lw snxt x_memorig x_memorig_bh ///
		 month_b4ch month_aftch childyoung childfirst lchmor 
		 
   order pidp pid wave ivfio doiy doim  intd_cu intd_pre ///
		 x_strata x_psu sppid_bh sppid new_hid ///
		 howlng n_husits n_husits2  ///
		 sex  x_birthy age ///
		 nchild chagemin new_mastat par_dur  parbgyr   ///
		 edu3c x_race religion_dum  new_hlstat country ///
		 scopfam* gender_liberal4f gender_liberal3f ///
		 workhrall jbstat jbstat_new employed  new_jbft ///
		 fimngrs_dv fimngrs15 fihhmn_all15 lnfimnlabgrs lnfimngrs lnfimnnet lnfihhmn ///
		 hh_xhweight  xweight lrwght lrwt* *_lw snxt ///		 
		 month_b4ch month_aftch childyoung childfirst lchmor x_memorig_bh x_memorig	
 
		 
	count if sppid_bh~=.&sppid~=. //no sppid filled in both BHPS and UnSoc
	
	gen double sppid_unif=sppid_bh //new var use bhps sp id if has it
	replace sppid_unif=sppid if sppid_unif==. //uses ukhls sp id if empty for that wave
	la var sppid_unif "new:BH and UKHLS sppid in one variable"
	format sppid_unif %12.0f
	order pidp wave sppid_unif sppid_bh sppid 
	
/*
*----------------Data Information-----------------*
//this info would be saved in folder "Data_desc"
	desc //where you wil find the meta-descriptions of the variables in this data set
	sum
	labelbook, detail
	codebookout  4191codebook
	estpost summ
	logout, save(result) excel word replace: summarize
*/	
	
save "$WorkData\equity1_pooled.dta",replace 

*A Partner Data to be merged with Individuals separately
	*BHPS: pid and sppid_bh are paired
	*UKHLS: pidp and sppid are paired

use "$WorkData\equity1_pooled.dta", clear
	order new_hid pidp pid
	drop doiy doim intd_* x_strata x_psu new_hid sppid_bh sppid childyoung childfirstbd
	drop *_lw lrwght lrwt*
	
	gen double pid_unif=pid if wave<19
	replace pid_unif=pidp if wave>18
	format pid_unif %12.0f
	order pid_unif wave
	la var pid_unif "new:x-sectional ID either pid or pidp in 1 var"
	
drop sppid_unif
	rename pid_unif sppid_unif
	
	rename * sp_*
	rename (sp_wave sp_sppid_unif) (wave sppid_unif)
	
	*duplicates report sppid_unif wave
save "$WorkData\equity1_pooledsp.dta", replace //to be matched to the individual records


use "$WorkData\equity1_pooled.dta", clear
	merge n:1 sppid_unif wave using "$WorkData\equity1_pooledsp.dta"
	
drop if _merge==2 //from using
	count	
	
	rename _merge parmerge //bhps partnership merge condition	
	la var parmerge "new:whether merged with a partner record"
	ta parmerge if ivfio==1&sppid_unif~=.
	//resp who are full interviewed and partnered together, how many can be matched? 92.3% matched
	
	sort pidp wave
	order pidp pid wave ivfio parmerge sppid_unif sppid_bh sppid new_mastat parbgyr
	ta new_mastat parmerge if ivfio ==1, row  //living as couple, more mismatched
	
*New Couple ID: follow pid if having pid, using us_pid if no pid(not from BHPS)
capture drop cpid
	order pidp wave sppid_unif sppid_bh sppid parbgyr
	gen double new_sppid=sppid_bh
	format new_sppid %12.0f
	order pidp wave new_sppid
	bysort pidp:replace new_sppid=new_sppid[_n-1] if ///
		sppid_bh==.&sppid~=.&parbgyr==parbgyr[_n-1]
	//continue using bhps sppid if same partner	
	replace new_sppid=sppid if new_sppid==.
	la var new_sppid "new:use sppid_bh if continues"
	
	count if new_sppid==.&sppid_bh~=.
	count if new_sppid==.&sppid~=.
	
	sort pidp wave	

save "$WorkData\equity1_pooledcp.dta", replace //partner's info now in

erase "$WorkData\equity1_pooledsp.dta"
erase "$WorkData\equity1_pooled.dta"


*--------------------------------------------------------------------------------*	
*Data Clean： Fill in Missing Values
*--------------------------------------------------------------------------------*
use "$WorkData\equity1_pooledcp.dta", clear

  	count if doiy==. 
	ta sex,m
	ta sex sp_sex,m
	 
	 sum age //5 to 104
	 sum x_birthy  //1894 to 2011
	 count if age==. 
	 
	 ta wave if age==. //wave 9 to 25
	 sum age
	 
*1. Age of the Youngest child in the Household:	
	ta chagemin if nchild==0,m
	replace chagemin=. if chagemin<0 | nchild==0
	count if chagemin==.&nchild>0 
	replace chagemin=sp_chagemin if sp_chagemin~=.&chagemin==.
	
	sum chagemin //0 to 15
	
*2. Number of dependnet child in household <=15:	
	replace nchild=0 if chagemin>15&chagemin~=. 
	sum chagemin if nchild==0 // 
	sum chagemin if nchild>0 //0 to 15
	replace chagemin=. if chagemin>15 //set chagemin to 0 to 15
	*ta nchild if chagemin~=.,m //if having the age of the youngest child, all have >=1 children in HH
	sort pidp wave		
	 
*3. Fill in Some Variables:
	 order pidp wave x_race religion_dum  edu3c
	 
	 replace new_mastat=sp_new_mastat if sp_new_mastat~=.&new_mastat==.
	 
    *3.1. fill in x-sectional variables using earlier records:
	 bysort pidp (wave): replace edu3c=edu3c[_n-1] if edu3c==.
	 bysort pidp (wave): replace x_race=x_race[_n-1] if x_race==.
	 bysort pidp (wave): replace religion_dum=religion_dum[_n-1] if religion_dum==.
	 bysort pidp: replace sp_religion_dum=sp_religion_dum[_n-1] if ///
									sp_religion_dum==.&new_sppid==new_sppid[_n-1]&new_sppid~=.
	 bysort pidp: replace sp_edu3c=sp_edu3c[_n-1] if sp_edu3c==.&new_sppid==new_sppid[_n-1]&new_sppid~=.
	 bysort pidp: replace sp_x_race=sp_x_race[_n-1] if sp_x_race==.&new_sppid==new_sppid[_n-1]&new_sppid~=.
							
    *3.2. fill in using later records:
	 gsort pidp -wave
	 bysort pidp: replace edu3c=edu3c[_n-1] if edu3c==.
	 bysort pidp: replace x_race=x_race[_n-1] if x_race==.	 
	 bysort pidp: replace religion_dum=religion_dum[_n-1] if religion_dum==.
	 bysort pidp: replace sp_edu3c=sp_edu3c[_n-1] if sp_edu3c==.&new_sppid==new_sppid[_n-1]&new_sppid~=.
	 bysort pidp: replace sp_religion_dum=sp_religion_dum[_n-1] if ///
									sp_religion_dum==.&new_sppid==new_sppid[_n-1]&new_sppid~=.
	 bysort pidp: replace sp_x_race=sp_x_race[_n-1] if sp_x_race==.&new_sppid==new_sppid[_n-1]&new_sppid~=.

	 sort pidp wave
	 
	*3.3. Fill in using spouse's info:
	 sum par_dur
	 replace par_dur=sp_par_dur if sp_par_dur~=.&par_dur==.
	 sum par_dur
	 
*4. Interview history variable construction:	
	gen doiy_pre=.
	bysort pidp (wave): replace doiy_pre=doiy[_n-1]
	order pidp wave doiy doiy_pre
	count if doiy<doiy_pre&doiy_pre~=.
	
	gen doiy_nxt=.
	bysort pidp (wave): replace doiy_nxt=doiy[_n+1]
	count if doiy>doiy_nxt&doiy_nxt~=. 
	la var doiy_pre "pidp: yr of previous record-full int"
	la var doiy_nxt "pidp: yr of next record-full int"
	
	gen intd_nxt=.
	bysort pidp (wave): replace intd_nxt=intd_cu[_n+1]
	count if intd_cu>intd_nxt&intd_nxt~=.
	
	order pidp wave doiy doiy_pre doiy_nxt intd_cu intd_nxt
	
*5. Age Squared term:
	gen agesq=age*age
	gen sp_agesq=sp_age*sp_age
	
keep if ivfio==1

note: adult All Age, full interview			
save  "$WorkData\equity1_fullint.dta", replace

erase "$WorkData\equity1_pooledcp.dta"

