***************************************************************************************************
*Data: UKHLS Harmonized BHPS IN
*1. Get Key Variables Clarified
***************************************************************************************************
 clear
 set more off
 do "C:\Users\Muzhi\OneDrive - Nexus365\Research\GenderDivision_Fertility\Stata2019\Do_edt\equity0_dir"
 capture log close 
 log using "$Output\equity2_indi_var", replace //log file 
	 
 set seed 13579

*-------------------------------------------------------------------------------------------* 
* Key Variables: Individual Level
*-------------------------------------------------------------------------------------------* 
	use "$WorkData\equity1_fullint.dta", clear //all full-interview records
	sort pidp wave
		ta sex 
		ta wave 
		
*Whether new child in next wave:
//if using the final sample with couples only, cannot be sure whether the last observation is due to 
//1. no full-interview in next wave or 2. divorced in nxt wave

*Couple ID:
	*codebook new_pid new_sppid
	gen double cpid=pidp*(10^11)+new_sppid+1
	format cpid %28.0f
	order pidp new_sppid cpid wave 
	sort pidp wave
	*duplicates report cpid wave if cpid~=. //no duplicated cpid for each wave, ok
			
	bysort pidp (wave): egen wavemin_pid=min(wave)
	la var wavemin_pid "pidp: first full int wave#"
	
	bysort pidp (wave): egen intymin_pid=min(doiy)
	la var intymin_pid "pidp: first full int year"
	
	bysort pidp (wave): egen wavemax_pid=max(wave)
	la var wavemax_pid "pidp: last full int wave#"
	
	bysort pidp  (wave): egen intymax_pid=max(doiy)
	la var intymax_pid "pidp: last full-int year"	

*Number of children in the next full interview:	
	gen nchildnxt_pid=.
	bysort pidp (wave): replace nchildnxt=nchild[_n+1] if nchildnxt==.
	la var nchildnxt_pid "pidp:number of own children in the next full interview"
	order pidp wave nchild nchildnxt_pid chagemin 
		
	ta nchildnxt_pid if wave~=wavemax_pid,m //no missing, only missing for last wave interviews
	

*Age of children in the next full interview:
	gen chageminnxt_pid=.
	la var chageminnxt_pid "pidp:age of the youngest child in next full interview"
	bysort pidp (wave): replace chageminnxt_pid=chagemin[_n+1] if chageminnxt_pid==.
	
*Marital status in the next full interview:
	gen mastatnxt_pid=.
	bysort pidp (wave): replace mastatnxt_pid=new_mastat[_n+1] if mastatnxt_pid==.
	la val mastatnxt_pid mastatnew
	la var mastatnxt_pid  "pidp:marital status in nxt full interview"

*Partnership status changed in the next full interview:
	gen parform_cu=0
	bysort pidp (wave): replace parform_cu=1 if cpid[_n-1]==.&cpid~=.
	replace parform_cu=. if wave==wavemin_pid
	la var parform_cu "pid: whether forming new partnership in this full interview"
	*order pidp wave cpid nchild mastatnxt_pid new_mastat parform_cu
	ta parform_cu if cpid~=. //new partnerships formed over this period: 
	ta parform_cu if cpid~=.&age>20&age<50&sex==1	
	
	gen parchangenxt=0 //not necessarily dissolve, can repartner within one year
	bysort pidp (wave): replace parchangenxt=1 if cpid~=cpid[_n+1]&cpid~=. //now having partner, but next either no or new partner
	replace parchangenxt=. if wave==wavemax
	la var parchangenxt "pid:partnership changed in next full interviews"
	order pidp wave cpid pidp sppid sp_pidp parchangenxt parform_cu new_mastat mastatnxt_pid
	ta parchangenxt,m
	ta parchangenxt if wave<wavemax,m // changed partnership status in the next record
	
*Race and Religion:
	ta x_race,m 
	ta religion_dum, m 
	
*Age of having the first child - not used later:
	*year having 1st child:
	sum childfirstbd
	sum x_birthy
	gen childfirstby=int(1900+childfirstbd/12)
	la var childfirstby "new:first child birth year"
	gen x_age1stp=childfirstby-x_birthy
	sum x_age1stp
	
	count if x_age1stp<0 //82 cases
	la var x_age1stp "new:age having 1st child"
	replace x_age1stp=age-chagemin if x_age1stp<0&chagemin~=.
	
	*list pidp wave x_age1stp x_birthy childfirstby sex age nchild chagemin if x_age1stp<0 
	replace x_age1stp=. if x_age1stp<15
	*hist x_age1stp
	*table wave sex, c(mean x_age1stp)
	*ta x_age1stp,m
	
*Divide the samples into 3 periods:
	recode wave 1/10=1 11/18=2 19/26=3, gen(period3_n)
	*table period3_n, c(min doiy max doiy)
	la def period3_n 1 "1991 to 2000" 2 "2001 to 2008" 3 "2009 to 2017"
	la val period3_n  period3_n 
	
*Categorize age of the youngest child - 
//having the potential to colinear with age and partnership duration:
	sum chagemin
	sum chagemin if nchild==0
	replace chagemin=. if nchild==0
	
	recode chagemin 0=0 1/3=1 4/6=2 7/10=3 11/15=4, gen (chagemin_c)
	replace chagemin_c=0 if nchild==0
	la def chagemin_c 0 "age 0/no child" 1 "1-3yr" 2 "4-6yr" 3 "7-10yr" 4 ">=11yr"
	la val chagemin_c chagemin_c
	ta chagemin chagemin_c,m
	
	*codebook n_mastat
	 gen cohab=[new_mastat==1]
	 replace cohab=. if new_mastat==.

	 recode nchild 0=0 1=1 2/10=2, gen(nchild3c)
	 la def nchild3c 0 "no own child in hh" 1 "one child" 2 ">=2 children"
	 la val nchild3c nchild3c
	 ta nchild nchild3c, mi	
 	 
*Health variable is not consistent across two surveys:
	ta wave new_hlstat, nof row
	ta new_jbft employed, mi
	 
save "$WorkData\equity2_pidpvar.dta", replace	 
note: selected full interview, having both women and men (full age range) from all waves

erase "$WorkData\equity1_fullint.dta"
