*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
*Data: UKHLS Harmonized BHPS together
*Prepare Sample for Latent Class Analysis, which will use Plugin in Do file 
* Sample: select couples, with successful match, partner also full interview
* Women as the main Respondent, aged 20 to 44, their partners aged 20 to 59
*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
 clear
 set more off
 do "C:\Users\Muzhi\OneDrive - Nexus365\Research\GenderDivision_Fertility\Stata2019\Do_edt\equity0_dir"
 *do "C:\Users\Muzhi\OneDrive - Nexus365\Research\GenderDivision_Fertility\Stata2019\Do\equity0_dir"
 capture log close 
 log using "$Output\equity3_cpvariable", replace //log file
	
*****************************************************************************
*1.1 Select Couples and Create Couple-Level Variable
*****************************************************************************
use "$WorkData\equity2_pidpvar.dta", clear	
	ta ivfio,m
	count //574559
	drop if age==.|sex==.
	
	ta country,m 
	order cpid pidp sppid_unif wave	
	keep if sex==1 //women as the main respondent 295191
	sum age //aged 15-104, female	
	
*-----------------------------------------------------------------------------------------------------*	
*Couple Sample Restriction: 1. matched; 2. both full interview (no need); 3. age restriction
*-----------------------------------------------------------------------------------------------------*
*1. CP sample selection:
	keep if cpid~=. //couples only
	ta sp_ivfio
	ta sp_ivfio sp_edu3c //91.2% has a full interviewed partner
	ta sp_ivfio sp_new_hlstat,m
	ta parmerge //90% has matched partner's record
	keep if sp_ivfio==1
	keep if parmerge==3
	count	
	
*2. Couple Age Restriction	
	sum age //
	drop if age<20
	drop if age>44
	drop if sp_age<20
	drop if sp_age>59&sp_age~=.

	sum age 
	sum sp_age //women aged 20 to 44, with their partners aged 20 to 59	
	count
	
	
*3. Others: No Northern Ireland
	drop if country==4|country==.
	drop if sex==sp_sex
	
*4. No full-time student for either the wife or the husband:
	ta jbstat
	drop if jbstat==7|sp_jbstat==7
	*xtset cpid wave
	ta wave
	*xtdes 
	count
	ta jbstat employed,m 
	

*-------------------------1.1 Couple level variables-------------------------------------*
	*1. Create couple Weight:
	sum xweight 
	count if xweight>2.5 
	//truncation applied following the user guide, see weight do file in stata common folder 
	//already recaled, no need to recale again
	ta wave if xweight>2.5&xweight~=. //from wave 7
	replace xweight=2.5 if xweight>2.5&xweight~=.
	
	 gen cpxweight=xweight*sp_xweight/hh_xhweight //all reversed probability
	 la var cpxweight "x-sect couple full-int weight-not scaled" 

	*table wave, c(max cpxweight mean cpxweight)
	replace cpxweight=6.25 if cpxweight>6.25&cpxweight~=. 
	
	sort pidp wave
	count if cpxweight==0|cpxweight==. 
	count if hh_xhweight==0|hh_xhweight==.
	count if xweight==0|xweight==.
	//couple weight may not be correct, if missing in household weight, also missing in couple weight
	//reformulate the question to what type of partnership are most 
	//likely for women if using individual weight
	ta wave if xweight==0 //from wave 7?!, too many from wave 21

	
*--------------------------------------------------------------------------------------------------*
*1.2. Couple-level variables:
*Spouse's proxy interview and those without matching spouse are kept in order to 
*maximize informaiton on birth in next wave
*---------------------------------------------------------------------------------------------------*
	order pidp wave cpid sp_ivfio parmerge wave 

*For Couples-Housework in a normal week percentage(will miss around 10% of the samples!):
		sum howlng //0-97
		sum sp_howlng //0-97
		
		gen howlng_tot=howlng+sp_howlng
		la var howlng_tot "new: sum of own and partner's hw hr"
		sum howlng_tot //0 to 150		

		ta wave if howlng==. //missing a lot in waves 1,19,21,23,25
		replace howlng_tot=. if cpid==.
		
		count if  howlng_tot==0 //couples with zero total housework time
		
		recode howlng_tot 0/14=1 14.001/20=2 20.001/28=3 28.001/150=4, gen(howlng_tot4call)
		la def howlng_tot4call 1 "0-14hrs" 2 "15-20hrs" 3 "21-28 hrs" 4 ">28hrs"
		la val howlng_tot4call howlng_tot4call
		ta howlng_tot4call, m	
		ta howlng_tot4call
		la var howlng_tot4call "unweighted tot housework hrs-4 quintile"
					
		gen howlng_percent=round(howlng/howlng_tot,0.001)
		*format howlng_percent %9.3f
		sum howlng_percent, d
		ta  howlng_percent if howlng_tot==0 //missing if zero total housework hours, good		
		replace howlng_percent=0.500 if howlng_tot==0 //can be 0.500 actually, 86 cases
		la var howlng_percent "own housework hr %"
		
		recode howlng_percent 0/0.249=1 0.250/0.499=2 0.500/0.749=3 0.750/1=4, gen(howlng_percentc)		
		la def howlng_percentc 1 "0-25%" 2 "25%-50%" 3 "50%-75%" 4 "75-100%"
		la val howlng_percentc howlng_percentc
		
		order cpid pidp wave howlng sp_howlng howlng_tot howlng_percent howlng_percentc
		
*For Couples-Work Hour in a normal week percentage(will miss around 10% of the samples!):
//spouse proxy may miss work hour info		
	  *Zero working hours if currently not working, now it is missing values:
	   **Total work hours:
	   ta new_jbft,m
	   ta sp_new_jbft,m //husband side missing too many
	   ta sp_new_jbft if sp_ivfio==1,m
	   table new_jbft, c(mean workhrall max workhrall min workhrall)
	   table sp_new_jbft, c(mean sp_workhrall max sp_workhrall min sp_workhrall)
	   
	   //missing working hours meaning not working for paid jobs
	    
	    tab jbstat if workhrall==. //some having work status but no work hours
	    tab sp_jbstat if sp_workhrall==.  
	    sum workhrall
	    sum sp_workhrall
		
	  //fill in working hours as zero if not working
		replace workhrall=0 if new_jbft==3
		replace sp_workhrall=0 if sp_new_jbft==3
		
		gen float tworkhr=workhrall+sp_workhrall
		sum tworkhr 
		la var tworkh "sum of couples' working hours"	
		count if tworkhr ==0 
		count if tworkhr==. 
				
		gen float workhr_percent=round((workhrall)/(tworkhr),0.001)
		format workhr_percent %9.3f
		sum workhr_percent, d
		la var workhr_percent "percentage of own working hour"		
		replace workhr_percent=0.500 if tworkhr==0|new_jbft==3&sp_new_jbft==3 //if none is working, share equally
		
		sum workhr_percent 
		recode workhr_percent 0/0.249=1 0.250/0.499=2 0.500/0.749=3 0.750/1=4, gen(workhr_percentc)	
		replace workhr_percentc=. if workhrall ==.|sp_workhrall==. //missing if not couples
		la def workhr_percentc 1 "0-24%" 2 "25-49%" 3 "50-74%" 4 "75-100%" 
		la var workhr_percentc "women's share of total working hours" //total==0, women share 50%
		la val workhr_percentc workhr_percentc
		
		ta workhr_percentc if cpid~=.&sp_ivfio==1, m //missing if missing total working hours time
		*ta wave workhr_percentc, row //decline of women sharing 0-24% working hours; 
		//increase of women sharing 75-100% working hours
		count if tworkhr==.
		count if tworkhr==0	
		
		order pidp pid wave cpid parmerge sp_ivfio jbstat workhrall sp_jbstat ///
				sp_workhrall workhr_percent

**---------------------------------------------------------------------------------------------*
*LCA Indicators
**---------------------------------------------------------------------------------------------*	
	*table jbstat4c, c(min workhrall max workhrall mean workhrall)
	//family care and maternity leave can still have some working hours
	
	ta jbstat_new new_jbft,m
	ta workhrall if new_jbft==.
	table new_jbft,c(min workhrall max workhrall mean workhrall) 
	//workhrall updated to zero from missing if not working
	
	order cpid pidp wave jbstat jb* workhrall new_jbft
	
	
	gen cpempmatch=1     if new_jbft==1&sp_new_jbft==1
	replace cpempmatch=2 if new_jbft==1&sp_new_jbft==2
	replace cpempmatch=3 if new_jbft==1&sp_new_jbft==3
	replace cpempmatch=4 if new_jbft==2&sp_new_jbft==1
	replace cpempmatch=5 if new_jbft==2&sp_new_jbft==2
	replace cpempmatch=6 if new_jbft==2&sp_new_jbft==3
	replace cpempmatch=7 if new_jbft==3&sp_new_jbft==1
	replace cpempmatch=8 if new_jbft==3&sp_new_jbft==2
	replace cpempmatch=9 if new_jbft==3&sp_new_jbft==3
	la def cpempmatch 1 "w:ft h:ft" 2 "w:ft h:pt" 3 "w:ft h:nw" 4 "w:pt h:ft" ///
					  5 "w:pt h:pt" 6 "w:pt h:nw" ///
					  7 "w:nw h:ft" 8 "w:nw h:pt" 9 "w:nw h:nw"
	la val cpempmatch cpempmatch
	ta cpempmatch new_jbft ,m
	ta cpempmatch sp_new_jbft ,m
	
	recode cpempmatch 2/3=2 4=3 5/6=4 7=5 8/9=6, gen(cpempmatch6c)
	la def cpempmatch6c 1 "w:ft h:ft" 2 "w:ft h:pt/nw" 3 "w:pt h:ft" 4 "w:pt h:pt/nw" ///
						5 "w:nw h:ft" 6 "w:nw h:pt/nw"
	la val cpempmatch6c cpempmatch6c
	ta cpempmatch cpempmatch6c
	ta cpempmatch6c new_jbft
	ta cpempmatch6c sp_new_jbft
	la var cpempmatch6c "Couple Emp Status Match-6c"
	
	ta cpempmatch6c,m //6.19% missing, keep these now
	
	order pidp pid wave cpid cpempmatch6c  new_jbft sp_new_jbft

 *Women's Share of Housework:
 	ta howlng_percentc , m
	ta workhr_percentc, m
	capture drop howlng_wm4c
	capture la drop howlng_wm4c
	recode howlng_percent 0/0.499=1 0.500/0.749=2 0.750/0.899=3 0.900/1=4, gen(howlng_wm4c)	
	*ta howlng_percent howlng_wm4c
	la def howlng_wm4c 1 "0-50%" 2 "50-75%" 3 "75-90%" 4 ">90%"
	la val  howlng_wm4c howlng_wm4c
	ta howlng_wm4c,m 
	
	recode howlng_wm4c 3/4=3, gen(howlng_wm3c)
	la val howlng_wm3c howlng_wm4c
	ta howlng_wm4c howlng_wm3c
	la var howlng_wm4c "Filled housework share - Wm Category"
	order pidp pid wave cpid howlng sp_howlng howlng_wm4c howlng_tot
		
   *Extreme Women: need to recode housework category:
	recode howlng_percentc 1/3=0 4=1, gen(howlng_percentcwm)
	la def howlng_percentcwm 0 "0-75%(equal)" 1 ">=75%"
	la val howlng_percentcwm howlng_percentcwm
	la var howlng_percentcwm "housework share 2C"
	ta howlng_percentc howlng_percentcwm
	ta howlng_percentcwm sex, col 
	ta wave howlng_percentcwm, row //women's extrem share declines over time!

 *Women's Share of Income:
	sum fimngrs15
	sum sp_fimngrs15	
	
	count if fimngrs15==.&sp_fimngrs15==.
	count if fimngrs15<100&sp_fimngrs15<100 //429!
	
	replace fimngrs15=0 if fimngrs15<0
	replace sp_fimngrs15=0 if sp_fimngrs15<0	
	
	gen ln_cpincmngrs15=ln(fimngrs15+sp_fimngrs15+0.5)
	la var ln_cpincmngrs15 "new:Logged total monthly personal income for both"
	
	gen income_percent= round((fimngrs15/(fimngrs15+sp_fimngrs15)),0.001) 	
	count if income_percent==.
	replace income_percent=0.500 if fimngrs15<300&sp_fimngrs15<300	
	//the percentage is 50% if both have less than 300 pounds per month
	
	order cpid wave fimngrs15  sp_fimngrs15 income_percent
	sum income_percent,d //women's share of couple's income
	
	recode income_percent 0/0.199=1 0.200/0.399=2 0.400/0.599=3 0.600/1=4, gen(incpwm4c)
	la def incpwm4c 1 "<20%" 2 "20-40%" 3 "40-60%" 4 ">60%"
	la val incpwm4c incpwm4c
	*ta income_percent incpwm4c
	ta incpwm4c, m
	la var incpwm4c "women's share of couple's income"
	order pidp pid wave cpid fimngrs15 sp_fimngrs15 incpwm4c 
	
	
 *Categories of Women's Share of Working Hours:	
	ta workhrall,m
	*table jbstat4c, c(min workhrall mean workhrall) //missing if inactive
	ta workhr_percentc, m //need recode
	recode workhr_percent 0/0.100=1 0.101/0.300=2 0.301/0.500=3 0.501/1=4 .=5, gen(workhrwm5c)
	la def workhrwm5c 1 "<10%"  2 "10-30%" 3 "30-50%" 4 ">50%" 5 "total hr=0"
	recode workhrwm5c 5=3 //if none is working, share the time equally!
	replace workhrwm5c=. if workhrall==.|sp_workhrall==. 
	la val workhrwm5c workhrwm5c
	ta workhrwm5c, m	
	order pidp pid wave cpid workhrall sp_workhrall  workhr_percent workhrwm5c 
		
*Who is responsible for childcare - ask if lives with spouse or partner and 
*children aged 12 or under live in HH for BHPS
*the age is changed to 15 in UnSoc
*Not asked in waves 3, 19, and 26
		*codebook n_husits
		ta wave n_husits, m
		ta wave n_husits2, m //wave 2 - a different way of asking
		ta wave n_husits, row nof
		
		order cpid wave chagemin nchild n_husits
		ta wave n_husits if nchild>0&chagemin<12, row
		ta wave n_husits if n_husits~=0, row nof
		
		ta chagemin if n_husits==0&wave<19 //many children older than 12 are now in this group
		ta chagemin if n_husits==0&wave>18 //chagemin should be 16+ in this group
	
	count	
save "$WorkData\equity3_var_cpid.dta", replace

erase "$WorkData\equity2_pidpvar.dta"

