*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
*Data: UKHLS Harmonized BHPS IN
*Project: HOusehold Typology and Fertility
*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
 set seed 339487731
 
 clear
 set more off
 do "C:\Users\Muzhi\OneDrive - Nexus365\Research\GenderDivision_Fertility\Stata2019\Do_edt\equity0_dir"
 capture log close 
 log using "$Output\equity4_desc", replace //log file 
 
*------------------------------------------------------------------------------------------------------------------------*
*Load Data
*------------------------------------------------------------------------------------------------------------------------*
use "$WorkData\equity4_lca_merged.dta" , clear 
count //63819 
	svyset, clear
	svyset x_psu [pweight = hh_xhweight /*xweight*/], strata(x_strata) singleunit(certainty)

	ta country //no Northern Ireland
	ta nchild3c,m
	sum chagemin //aged 0 to 15
	sum age //wife 20 to 44
	sum sp_age //husband 20 to 59
	
	ta cpempmatch6c,m
	ta howlng_wm4c,m
	ta new_jbft, m
	ta sp_new_jbft, m
	ta incpwm4c,m 
	ta workhrwm5c,m 
	ta nchild3c,m
	
*Child age with no missing value:
	table nchild, c(mean chagemin max chagemin) //chagemin is missing if no child at home
	gen chageminall=chagemin
	replace chageminall=0 if chagemin==.&nchild==0
	la var chageminall "new:youngest child's age(no child filled)"
	
*Birth cohort:
	ta x_birthy
	recode x_birthy 1947/1964=1 1965/1974=2 1975/1998=3, gen(cohort_b)
	la def cohortb 1 "(1965)before 1965" 2 "1965/1974" 3 "after 1975(1985)"
	la val cohort_b cohortb
	ta x_birthy cohort_b

*Recode health self-reported values:
    recode new_hlstat 4/5=4 //poor and very poor into one category because too few in very poor condition
	recode sp_new_hlstat 4/5=4	
	ta new_hlstat	
	ta sp_new_hlstat

	
*Rescaled Weight - All wave IN: 
//see pdf file in D:\Academia\Data\UKUSoc, file name:Pooling data from different waves
	order pidp cpid wave xweight hh_xhweight period3_n
	bysort wave: gen totn=_N //total observations in each wave
	la var totn "total # of observations in each wave"
	
 *Note: If Currently dropped BHPS wave 1 as no housework info, starting from wave 2
 *If full waves all in, starting from BHPS wave 1
 *Keep wave 19 for more samples in FE analysis - 
	gen totn_a=totn if wave==1
	replace totn_a=totn_a[_n-1] if totn_a==.
	la var totn_a "total # of observations in wave 1"
	
	order pidp cpid wave xweight hh_xhweight totn totn_a
	
	*duplicates report new_hid wave //very few have duplicated household id - several couples in one household
	gen xhweight_scale=.
	replace xhweight_scale=hh_xhweight*(totn_a/totn)
	la var xhweight_scale "rescaled household x-sectional weight:ref wave 1"
	
	gen xweight_scale=.
	replace xweight_scale=xweight*(totn_a/totn)
	la var xweight_scale "rescaled individual x-sectional weight:ref wave 1"

	
*************************************************************************************
*Descriptive Statistics:
*************************************************************************************
	svyset, clear
	svyset x_psu [pweight = xhweight_scale], strata(x_strata) singleunit(certainty) //scaled weighting used!

*Samples including all waves used for descriptive analysis, data visualization:
*Not dropping missing info for any variables
*[Figure 2]: showing the distribution trend of the lca classes:
	svy: ta cptypo_all wave, col 
	
	sum chagemin if nchild==0 //no value if no child at home
	
	table wave , c(mean nchild median nchild mean chagemin) 
	table wave [pweight = xhweight_scale], c(mean nchild median nchild mean chagemin) //same as the above one


*Missing Data and sample selection!	
 *No need to Drop LCA indicators missing records:	
 //LCA can fill in a class with missing info in one or more indicators, no need to drop these?
	*drop if cpempmatch6c==.|incpwm4c==.|howlng_wm4c==.
	count
	xtset cpid wave
	*xtdes //where you will find the sample size before dropping any missing
	
	
 *Drop variables used in all models:	
	drop if chagemin==.&nchild>0
	drop if cohab==.|nchild==.
	drop if par_dur==.	
	
	capture drop nwave
	bysort cpid: gen nwave=_N
	
	order cpid wave nwave
	count
	*xtdes 
	*xtdes if nwave>1 	
	//here you will find the proportion of the couples who remained for more than one wave
	
*rescale the selected waved data AGAIN: 
// see pdf file in D:\Academia\Data\UKUSoc, file name:Pooling data from different waves
	
	bysort period3_n: gen totn_p=_N //total observations in each wave
	la var totn_p "total # of observations in each period"
	gen totn_p1=totn_p if period3_n==1
	replace totn_p1=totn_p1[_n-1] if totn_p1==.
	la var totn_p1 "total # of observations in Period 1"
	
	order pidp cpid wave xweight totn_p totn_p1
	gen xweight_scalep=.
	replace xweight_scalep=xweight*(totn_p1/totn_p)
	la var xweight_scalep "rescaled individual x-sectional weight-base period 1"
	order pidp cpid wave xweight totn_p totn_p1 xweight xweight_scalep	
	
	gen xhweight_scalep=.
	replace xhweight_scalep=xweight*(totn_p1/totn_p)
	la var xhweight_scalep "rescaled household x-sectional weight-base period 1"
	
	svyset, clear
	svyset x_psu [pweight = xhweight_scalep], strata(x_strata) singleunit(certainty)
	
desc	
save "$WorkData\equity5_lca_cpsample.dta", replace	
note: All waves in for descriptive analysis of a sample



erase "$WorkData\equity4_lca_merged.dta"

*************************************************************************************************
*-----Cross-sectional Sample: Descriptive Statistics By Period 	
*************************************************************************************************

use  "$WorkData\equity5_lca_cpsample.dta", clear
	count
 *Drop variables used in x-sectional analysis ONLY:
	drop if edu3c==.|sp_edu3c==.
	drop if new_hlstat==.|sp_new_hlstat==.
	drop if religion_dum==.|x_race==. //reserved from cross-sectional analysis ONLY
	//variables not used for FE analysis, thus not dropping them before
	
	ta wave cpempmatch6c,m
	ta howlng_wm4c,m 
	ta wave howlng_wm4c,m //waves 1, 19, 21, 23 and 25
	ta new_jbft, m
	ta sp_new_jbft, m
	ta incpwm4c,m 
	ta workhrwm5c,m 
	ta nchild3c,m
	count
	*drop if cpempmatch6c==.|howlng_wm4c==.|incpwm4c==. //no need to drop those as LCA can fill in
	di 60548/63819  //denominator dropped those included in both panel and x-sectional models - 94.8%
	
	svy: ta cptypo_all wave, col  //Fig 2 trend
	
	
	
*1. Samples in each period:
	svy:ta period3_n, col
	xtdes
	count
	xtdes if period3_n==1
	count if period3_n==1
	
	xtdes if period3_n==2
	count if period3_n==2
	
	xtdes if period3_n==3
	count if period3_n==3
	
	
*1. Typology:
	svy: ta cptypo_all period3_n, col
		
	sum workhr_percent
	sum income_percent
	sum howlng_percent
	table period3_n [pweight = xhweight_scalep], c(mean workhr_percent mean income_percent mean howlng_percent)

	
*2. Each Indicator of the Typology:	
	svy: ta cpempmatch6c period3_n, col
	svy: ta incpwm4c   period3_n, col
	svy: ta howlng_wm4c period3_n, col
	
*3. Children info:
	gen parentdnew=[nchild>0]
	svy: ta parentdnew period3_n, col
	sum nchild

	table period3_n [pweight = xhweight_scalep], c(mean nchild median nchild)
	table period3_n , c(sd nchild)
	
	sum chagemin
	sum chageminall
	table period3_n [pweight = xhweight_scalep], c(mean chagemin median chagemin)
	table period3_n , c(sd chagemin)
	
*4. Age
	sum age
	sum sp_age
	table period3_n [pweight = xhweight_scalep], c(mean age mean sp_age)
	table period3_n , c(sd age sd sp_age)
	
*5. Marital Info:
	svy: ta cohab period3_n, col
	sum par_dur
	sum par_dur if par_dur>0 //number of years
	table period3_n if par_dur>0 [pweight = xhweight_scalep], c(mean par_dur)
	table period3_n if par_dur>0, c(sd par_dur)	
	
*6 household monthly income:
	*Gross Couple ones:
	gen n_cpincmngrs15=fimngrs15+sp_fimngrs15
	la var n_cpincmngrs15 "new: cp monthly gross income adj2015"
	sum n_cpincmngrs15,d
	table period3_n [pweight = xweight_scalep], c(median n_cpincmngrs15)
	table period3_n , c(sd n_cpincmngrs15)
		
	*Net ones:
	sum fihhmn_all15,d
	table period3_n [pweight = xweight_scalep], c(median fihhmn_all15)
	table period3_n , c(sd fihhmn_all15)	
	
*7. Couple Education:
	svy: ta edu3c period3_n, col
	svy: ta sp_edu3c period3_n, col
	
*Self-rated health, race, and relgioous
	ta new_hlstat,m
	ta sp_new_hlstat, mi	
	svy: ta new_hlstat period3_n, col
	svy: ta sp_new_hlstat period3_n, col
	
	ta x_race,m
	ta sp_x_race, m	
	svy: ta x_race period3_n, col
	
	ta religion_dum,m
	ta sp_religion_dum, m //many missing this
	svy: ta religion_dum period3_n, col	
	
*7. Location:	
	svy: ta country period3_n, col
	
	di 53107169+5299900+3063758 //2011 population UK
	di 53107169/61470827 //England 86.39%
	di 3063758/61470827  //Wales 4.98%
	di 5299900/61470827  //Scotland 8.6%
	
*8. Health:
	ta n_health period3_n,m

	svy: ta n_scsf1 period3_n, col
	svy: ta sp_n_scsf1 period3_n, col
		
	
*Couples Types and the Number of Children in the Household:	
	forval i=0/3{
	svy: ta lcatypo if nchild4c==`i'
	}
	** 
