*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
*Data: UKHLS Harmonized BHPS IN
*Project: HOusehold Typology and Fertility
*Models: Conditional Logistic Regression
*1.Predicting Birth Outcome using Couple Typology; Change over time
*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
 set seed 339487731 
 clear
 set more off
 do "C:\Users\Muzhi\OneDrive - Nexus365\Research\GenderDivision_Fertility\Stata2019\Do_edt\equity0_dir"
 capture log close 
 log using "$Output\equity7_Models_Birth", replace //log fil
 
*--------------------------------------------------------------------------------------------------*
*Load Data
*--------------------------------------------------------------------------------------------------*  
use "$WorkData\equity5_lca_cpsample.dta" , clear 
	//not dropping those waves without collecting housework info:
	count //fully restricted dropped waves with no housework info 49718
	count
	xtset cpid wave
	
	ta month_aftch
	
 *Two samples - 1. estimating all births; 2. estimating birth by birth orders, including more samples
	 *1. All births:
	drop if month_b4ch<12 //this one is used if we report all birth in one sample/model
	 *2. BY Parity, see line 359 and after:
	*drop if month_b4ch<6  //this one is used if we would like to separate samples by birth other, otherwise too small size unable to converge
		
*When is the next observation for the selected Couple sample, we have this info when doing individual sample:
	sort cpid wave pidp 
	
	gen doiynxt_ns=. //year of interview in the next wave-new sample with some waves dropped
	la var doiynxt_ns "restricted cp sample:yr of nxt interview"
	//the last wave, wave 7 in US, should use its info on 6th wave doiynxt
	bysort cpid: replace doiynxt_ns=doiy[_n+1] 
	replace doiynxt_ns=doiy_nxt if doiy_nxt~=.&doiynxt_ns==. //
	//because cp restricted so it is not in all cp records, fill in this info using all cp record
	count if doiynxt_ns>doiy_nxt&doiynxt_ns~=. //
	ta wave if doiynxt_ns>doiy_nxt&doiynxt_ns~=. //mostly in Unsoc where asked housework with gaps
	count if doiynxt_ns<doiy_nxt&doiy_nxt~=.
	drop if doiynxt_ns<doiy_nxt&doiy_nxt~=.
	
	
	gen intd_nxtns=.
	la var intd_nxtns "restricted cp sample:date of nxt interview"
	bysort cpid: replace intd_nxtns=intd_cu[_n+1] if intd_cu[_n+1]~=.
	replace intd_nxtns=intd_nxt if intd_nxt~=.&intd_nxtns==. //
	count if intd_nxtns>intd_nxt&intd_nxtns~=. //
	count if intd_nxtns<intd_nxt&intd_nxt~=.
	
	order pidp cpid wave intd_cu intd_nxt  ///
			intd_nxtns doiy doiynxt doiynxt_ns
	
*-----------------------------------------------------------------------------------------	
*Birth outcome update: 
*as some waves are dropped, for the current wave, whether new birth should further include subsequent
*waves further away - e.g. no new birth in the next wave as in full couple sample, 
*but can have new birth 2-3 waves after when
*some waves are dropped, thus need to update this information
//nchildnxt is from the couple sample - all couples in, all waves in - equity 3 do file
//nchildnxt_pid is from the individual full sample - equity 2 do file
*-----------------------------------------------------------------------------------------
  *1. whether new birth based on numbers of children:
	order cpid wave nchild nchildnxt_pid
		
	gen nchildnxt_ns=.
	bysort cpid (wave): replace nchildnxt_ns=nchild[_n+1] if nchildnxt_ns==.&nchildnxt_pid~=.
	replace nchildnxt_ns=nchildnxt_pid if nchildnxt_ns==.
	la var nchildnxt_ns "restricted cp sample:# of child in nxt interview"
	
	ta nchildnxt_ns if wave<wavemax,m 
	
	gen chaageminnxt_ns=.
	bysort cpid (wave): replace chaageminnxt_ns=chagemin[_n+1] if chaageminnxt_ns==.&chageminnxt_pid~=.
	replace chaageminnxt_ns=chageminnxt_pid if chaageminnxt_ns==.
	la var chaageminnxt_ns "restricted cp sample:age of youngest child in nxt interview"
	
	order cpid pidp wave nchild nchildnxt_pid nchildnxt_ns chagemin chageminnxt_pid chaageminnxt_ns
	
  *Whether update # of children in the following wave after dropping some waves:
 	gen gap_pid=doiy_nxt-doiy
	ta gap_pid if wave<wavemax,m
	
    gen nbnxt=[nchildnxt_ns>nchild&nchildnxt_ns~=.&chaageminnxt_ns<4]
	replace nbnxt=. if nchildnxt_ns==. //if last wave in the full waves couple sample - not necessarily...	
	la var nbnxt "new birth based on nchild"
	ta nbnxt if wave<wavemax,m 
	ta nbnxt if wave==wavemax,m  //all missing cases in last wave of the couple	

	ta mastatnxt_pid,m	
	
	*list cpid wave if chagenxt==.&nbnxt==1 //mostly higher waves, should be fine
	ta nbnxt if nbnxt==0&chaageminnxt_ns==0
	replace nbnxt=1 if nbnxt==0&chaageminnxt_ns==0 
	//changes made-although nchild may not change, can still hv child leaving and another in	
	replace nbnxt=1 if nbnxt==.&chaageminnxt_ns<4 //0 changes made
	*if next wave children younger than 4 but currently missing here
	ta nbnxt if parchangenxt==1,m
	replace nbnxt=0 if parchangenxt==1 
	//if changed partnership status/partners, should not hv a new born in the same partnership
	
	
  *2. Update interview gaps for cases with replaced nchildnxt:
	gen yrgap_ns= doiynxt_ns- doiy
	ta yrgap_ns,m //0-21 year
	ta yrgap_ns nbnxt,m //for this sample, 98.28% are followed up within 3 years
		
	gen monthgap_ns=intd_nxtns-intd_cu 
	sum monthgap_ns //4-224 months 
	la var monthgap_ns "restricted cp sample:#of month from current to nxt interview"
	count if monthgap_ns==.&nbnxt~=. //41 cases
	ta wave wavemax if monthgap_ns==.&nbnxt~=.
	ta intd_cu if monthgap_ns==.&nbnxt~=. //missing current int date
	replace monthgap_ns=intd_nxt-intd_cu if monthgap_ns==.&nbnxt~=.
	ta monthgap_ns  nbnxt,m
	ta yrgap_ns if monthgap_ns==.,m
	
 *2.1 Categorical interval variable:	
	recode monthgap_ns 0/11.5=0 12/23.5=1 24/35.5=2 36/500.5=3, gen(yrgapc)
	replace yrgapc=0 if monthgap==.&yrgap_ns ==0
	replace yrgapc=1 if monthgap==.&yrgap_ns ==1
	replace yrgapc=2 if monthgap==.&yrgap_ns ==2
	replace yrgapc=3 if monthgap==.&yrgap_ns >2&yrgap_ns ~=.
	
	la def yrgapc 0 "0-1yr" 1 "1-2yr" 2 "2-3yr" 3 "3yr+"
	la val yrgapc yrgapc
	ta monthgap_ns yrgapc  ,m //7333 missing
	ta yrgapc if wave<wavemax,m
	drop if yrgapc<0
	
*Interaction between couple typology and the period indicator:	
	recode cptypo_all 3=0 4=3 5=4, gen(lcatypo_new)
	ta lcatypo_new lcatypo , m //using egalitarian as the reference group
	la def lcatypo_new 0 "Dual-earner" 1 "Male-breadwinner" ///
					   2 "Modified male-breadwinner" 3 "Female-breadwinner" ///
					   4 "Precarious"
	la val lcatypo_new  lcatypo_new 
	ta lcatypo_new  cptypo_all
	ta lcatypo_new 
	
*----------------------------Coupledom styles interact with period indicators:------------------------------
	
*1. STATA LCA analysis  - all categorical indicators classificiations
	gen trap1=[lcatypo_new==1&period3_n==1]
	gen trap2=[lcatypo_new==1&period3_n==2]
	gen trap3=[lcatypo_new==1&period3_n==3]
	gen setrap1=[lcatypo_new==2&period3_n==1]
	gen setrap2=[lcatypo_new==2&period3_n==2]
	gen setrap3=[lcatypo_new==2&period3_n==3]
	gen egap1=[lcatypo_new==0&period3_n==1]
	gen egap2=[lcatypo_new==0&period3_n==2]
	gen egap3=[lcatypo_new==0&period3_n==3]
	gen nontrap1=[lcatypo_new==3&period3_n==1]
	gen nontrap2=[lcatypo_new==3&period3_n==2]
	gen nontrap3=[lcatypo_new==3&period3_n==3]
	gen precap1=[lcatypo_new==4&period3_n==1]
	gen precap2=[lcatypo_new==4&period3_n==2]
	gen precap3=[lcatypo_new==4&period3_n==3]

*Sample overview:
	drop if nbnxt==.
	count if wave==wavemax //all last obs dropped	
	drop if yrgapc==.
		
 //Still using nbnxt_cp as the dependent variable:
   *label samples that have this change:
	order cpid wave nbnxt nchild
	capture drop nbnxtcpmin nbnxtcpmax cpnxtdiff
	bysort cpid (wave): egen nbnxtcpmin=min(nbnxt)
	bysort cpid (wave): egen nbnxtcpmax=max(nbnxt)
	gen cpnxtdiff=[nbnxtcpmin~=nbnxtcpmax]
	
 //Correct Number of Couples (not couple-year records) who have experienced such a change!
	xtdes if cpnxtdiff==1 	
	//1. having birth within one year dropped - 2246 cases, all waves in
 	//2. having births within 6months dropped - 2864 cases, all waves in
	
**To paper: record following up period among those observations for FE analysis!
	ta yrgapc if cpnxtdiff==1
	ta yrgapc if cpnxtdiff==1&nbnxt==0
	ta yrgapc if cpnxtdiff==1&nbnxt==1 //still hv some 0-1yr gap, dropping those not change the result
	
	ta monthgap_ns if cpnxtdiff==1&nbnxt==0
	ta monthgap_ns if cpnxtdiff==1&nbnxt==1

/*	
*FE Sample Statistics:	
	xttab lcatypo_new if cpnxtdiff==1 //[Footenote 17]
	//great variations in both the division of labor type and the birth outcome
	//see Note 18 of this paper for our interpretations
	ta lcatypo_new if cpnxtdiff==1 
	ta lcatypo_new period3_n if cpnxtdiff==1 , col nof 
	sum nchild if cpnxtdiff==1 
	sum chagemin if cpnxtdiff==1 
	sum age if cpnxtdiff==1 
	sum sp_age if cpnxtdiff==1 
	ta cohab  if cpnxtdiff==1 
	ta cohab  period3_n if cpnxtdiff==1 
	sum par_dur if cpnxtdiff==1 
	table period3_n if cpnxtdiff==1, c(mean nchild mean chagemin mean par_dur mean age mean sp_age)
	//In later periods, more children, longer duration, older couples
*/	
	
	
*-------------------------------------------------------------------------------------*
*Predicting Birth Outcome 
//Age of the children dropped based on reviewers' comments, no change in conclusion made, though
*-------------------------------------------------------------------------------------*
	xtset cpid wave
	order cpid wave nbnxt
	
	set seed 339487731 
	set more off	
	eststo clear
	
*--------------------------I. The Effect of Typology--------------------------		
 	
 *I. Overall Birth Event:					
 *I1. Conditional Logistic model:	
		xtdes if cpnxtdiff==1	
		ta doiy if cpnxtdiff==1
		
		 xtlogit 	 nbnxt 	///
											i.lcatypo_new  i.period3_n  ///
											i.nchild3c /* chagemin*/ ///
											cohab par_dur  ///
											age agesq sp_age sp_agesq ///
											i.yrgapc ///
											 /*ln_cpincmngrs15*/, ///
											 fe 
		//note the smaller sample size if more variables are included
		//income: either sum of couple's personal monthly total income or household net total income
		//Logged household net income is not significant, but logged total household income is negative
		
		 eststo, ti ("parityall_fe"):   clogit 	 nbnxt 	///
											i.lcatypo_new  i.period3_n  ///
											i.nchild3c /* chagemin*/ ///
											cohab par_dur  ///
											age agesq sp_age sp_agesq ///
											i.yrgapc ///
											 /*ln_cpincmngrs15*/, ///
											 group(cpid) vce(robust)  
		//same estimates but std error considers clustering in cpid, very little difference, though
		
 *I2: Interaction with periods:
  *1. STATA LCA output:					
		eststo fe1inter, ti ("parityall_feint"): clogit    nbnxt 	///
										 i.lcatypo_new  i.period3_n ///
										 trap2 setrap2 /*precap2 nontrap2   */ ///
										 trap3 setrap3 /*precap3 nontrap3 */  ///					
										 i.nchild3c  ///
											cohab par_dur  ///
											age agesq sp_age sp_agesq  ///
											/*ln_cpincmngrs15*/ ///
											i.yrgapc ,group(cpid) vce(robust) 
				
		test 2.lcatypo_new
		//Including household total income not changing the conclusion and the estimates much
		//the effect of precarious couples shrink, though
		//make the model simpler,then
							
	 *Period interact with all division of labor types:					
	  clogit    nbnxt 	///
										 i.lcatypo_new  i.period3_n ///
										 trap2 setrap2 nontrap2  precap2   ///
										 trap3 setrap3 nontrap3  precap3  ///					
										 i.nchild3c  ///
											cohab par_dur  ///
											age agesq sp_age sp_agesq  ///
											i.yrgapc , group(cpid) vce(robust) 
											
	  *Binomial Logistic Model Predicting Childbirth in Next Wave using Couple Typology - Table Summary:
	  esttab using "$Output\2019.equity7_Model_birthfe.csv", replace nonum not nodep mti r2 ar2  ///
			starlevels(* 0.05 ** 0.01 *** 0.001) b(%9.3f) se ///
			ti("The Effect of Couple Typology on birth in Next Observations") ///
			la addnotes("conditional logit fixed effect model-unweighted")
		
*-----------------------------------------------------------------------------**
*II: Graph: Fixed logit
*------------------------------------------------------------------------------*	
	set more off

*1. STATA LCA output:
		gen tra=[lcatypo_new==1]
		la var tra "Male-breadwinner vs. Dual-earner"
		gen setra=[lcatypo_new==2]
		la var setra "Modified male-breadwinner vs. Dual-earner"
		gen ega=[lcatypo_new==0]
		gen nontra=[lcatypo_new==3]
		la var nontra "Female-breadwinner vs. Dual-earner"
		gen preca=[lcatypo_new==4]
		la var preca "Precarious vs. Dual-earner"
 
	    eststo Period_1991_2000, ti("1991/2000"): clogit    nbnxt ///
										 tra setra nontra preca i.period3_n ///
										 trap2 setrap2 /*nontrap2 precap2*/ ///
										 trap3 setrap3 /*nontrap3 precap3*/ ///			
										 i.nchild3c /*i.chagemin_c*/ cohab par_dur  ///
										 age agesq sp_age sp_agesq ///
										 i.yrgapc , group(cpid) vce(robust) nolog
		
		
		eststo Period_2001_2008, ti("2001/2008"):  clogit    nbnxt ///
										 tra setra nontra preca i.period3_n ///
										 trap1 setrap1 /*nontrap1 precap1*/ ///
										 trap3 setrap3 /*nontrap3 precap3*/  ///			
										 i.nchild3c /*i.chagemin_c*/ cohab par_dur ///
										 age agesq sp_age sp_agesq ///
										 i.yrgapc , group(cpid) vce(robust) nolog
										 
		eststo Period_2009_2017, ti("2009/2017"):  clogit    nbnxt ///
										 tra setra nontra preca i.period3_n ///
										 trap1 setrap1 /*nontrap1 precap1*/ ///
										 trap2 setrap2 /*nontrap2 precap2*/ ///			
										 i.nchild3c /*i.chagemin_c*/ cohab par_dur  ///
										 age agesq sp_age sp_agesq ///
										 i.yrgapc , group(cpid) vce(robust) nolog
											 
		*set scheme s1mono 
		*1. basic coefficient 
		//exponentiate the coefficient
		//using recast
		
		*Figure 3: By coefficient - exponentiate!
		 set scheme s2color
		coefplot (Period_1991_2000, eform  keep(tra setra) msymbol(D)  label(1992–2000)) ///
		(Period_2001_2008, eform  keep(tra setra) pstyle(p2dot) msymbol(Dh) label(2001–2008)) ///
		(Period_2009_2017, eform  keep(tra setra) pstyle(p10) msymbol(S) label(2009–2016) ), ///
		 xline(1) xlabel(0(0.5)4) xtitle ("Odds of having a child") ///
		 coeflabels(, wrap(5) nobreak)  ///
		 /*legend(off) mfcolor(white)*/ ciopts(lwidth(*2) lcolor(*.8)) ///
		graphregion(color(white)) bgcolor(white)
		
*************************************************************************************************************		
*III. Haudman test for Fixed and Random Effects:
*************************************************************************************************************
	set more off	
	eststo clear	
	
	eststo fe1: xtlogit 	 nbnxt 	///
											i.lcatypo_new  i.period3_n  ///
											i.nchild3c /* chagemin*/ ///
											cohab par_dur  ///
											age agesq sp_age sp_agesq ///
											i.yrgapc,fe nolog
											 
	
	gen resample=[nchild<3] //having 0-2 children in hh
	xtdes if resample 
	
	set more off
		eststo re1, ti ("parityall_re"):xtlogit nbnxt	i.lcatypo_new i.period3_n  ///
											i.nchild3c  ///
											cohab par_dur  ///
											age agesq sp_age sp_agesq  ///
											/* ln_cpincmngrs15 tworkhr*/ ///
											i.edu3c i.sp_edu3c    ///
											i.new_hlstat i.sp_new_hlstat ///
											i.x_race religion_dum i.country ///
											 if resample, re  nolog
											
		hausman fe1 re1			
			
*************************************************************************************************************		
*IV. By Birth Order:
 //Note: ONLY dropping ppl six months before births because the sample size is too small to converge
 //drop if month_b4ch<6 - this one mentioned at the top in this do file
*************************************************************************************************************
set more off	
	eststo clear
	*1. 1st child	
		xtlogit 	 nbnxt 	///
											i.lcatypo_new  i.period3_n  ///
											cohab par_dur  ///
											age agesq sp_age sp_agesq   ///
											i.yrgapc ///
											/*ln_cpincmngrs15*/ ///
											if nchild==0, fe nolog
		//712 couples with 2714 records
											
		eststo fe1st, ti ("1stb_fe"): clogit 	 nbnxt 	///
											i.lcatypo_new  i.period3_n  ///
											cohab par_dur  ///
											age agesq sp_age sp_agesq   ///
											i.yrgapc ///
											/*ln_cpincmngrs15*/ ///
											if nchild==0, group(cpid) vce(robust)
											
	  *Interaction: 1st child	  
	 	
	  eststo fefirstp, ti ("1stb_fep"):  clogit 	 nbnxt 		///
										i.lcatypo_new  i.period3_n ///
										trap2 setrap2 /*nontrap2 precap2 */ ///
										trap3 setrap3 /*nontrap3 precap3*/  ///
										cohab par_dur  ///
										age agesq sp_age sp_agesq ///
										/* ln_hh_fihhmngrs15  */ ///	
										i.yrgapc if nchild==0 ,group(cpid) vce(robust)
									
	*2. >=1 children
	    xtlogit 	 nbnxt ///
											i.lcatypo_new  i.period3_n  ///
											i.nchild3c  ///
											cohab par_dur ///
											age agesq sp_age sp_agesq ///
											/*ln_cpincmngrs15*/ ///
											i.yrgapc ///
											if nchild>0,fe nolog
		//2348 couples with 15649 records
		
		eststo fehigher, ti ("higherb_fe"):clogit 	 nbnxt ///
											i.lcatypo_new  i.period3_n  ///
											i.nchild3c  ///
											cohab par_dur ///
											age agesq sp_age sp_agesq ///
											/*ln_cpincmngrs15*/ ///
											i.yrgapc ///
											if nchild>0, group(cpid) vce(robust)	 
		
	  *Interaction: >=2 child	  
	  eststo fehigherp, ti ("higherb_fep"): clogit  nbnxt ///
										    i.lcatypo_new i.period3_n ///
										    trap2 setrap2 /*nontrap2 precap2*/ ///
											trap3 setrap3 /*nontrap3 precap3*/ ///	
											i.nchild3c  ///
											cohab par_dur ///
											age agesq sp_age sp_agesq   ///
											/* ln_hh_fihhmngrs15  */ ///	
											 i.yrgapc if nchild>0, group(cpid) vce(robust)	
											
		
    *Binomial Logistic Model Predicting Childbirth in Next Wave using Couple Typology - Table Summary:
	  esttab using "$Output\2019.equity7_Model_birthfebyorder.csv", replace nonum not nodep mti r2 ar2  ///
			starlevels(* 0.05 ** 0.01 *** 0.001) b(%9.3f) se ///
			ti("The Effect of Couple Typology on birth in Next Observations") ///
			la addnotes("conditional logit fixed effect model-unweighted")
		