*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
*Data: UKHLS Harmonized BHPS IN
*Project: HOusehold Typology and Fertility
*Models: Conditional Logistic Regression
*1.Predicting Couple Typology using # of Children in Household; Change over time
*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
 set seed 339487731 
 clear
 set more off
 do "C:\Users\Muzhi\OneDrive - Nexus365\Research\GenderDivision_Fertility\Stata2019\Do_edt\equity0_dir"
 capture log close 
 log using "$Output\equity8_Models_Cptype", replace //log file
 
*-----------------------------------------------------------------------------------------------------*
*Load Data
*-----------------------------------------------------------------------------------------------------*
use "$WorkData\equity5_lca_cpsample.dta" , clear
xtset cpid wave
	sum age //
	
*Recode Dep Var:
	recode cptypo_all 3=0 4=3 5=4, gen(lcatypo_new)
	ta lcatypo_new lcatypo , m //using egalitarian as the reference group
	la def lcatypo_new 0 "Dual-earner" 1 "Male-breadwinner" ///
					   2 "Modified male-breadwinner" 3 "Female-breadwinner" ///
					   4 "Precarious"
	la val lcatypo_new  lcatypo_new 
	ta lcatypo_new  cptypo_all
	ta lcatypo_new 
	
*Interactions:
		ta nchild nchild3c
		gen ch1p1=[nchild3c==1&period3_n==1]
		gen ch2p1=[nchild3c==2&period3_n==1]
		*gen ch3p1=[nchild4c==3&period3_n==1]
		
		gen ch1p2=[nchild3c==1&period3_n==2]
		gen ch2p2=[nchild3c==2&period3_n==2]
		*gen ch3p2=[nchild4c==3&period3_n==2]
		
		gen ch1p3=[nchild3c==1&period3_n==3]		
		gen ch2p3=[nchild3c==2&period3_n==3]
		*gen ch3p3=[nchild4c==3&period3_n==3]
		
		ta nchild3c ch1p2
		ta period3_n ch1p2								 

*-------------------Variables in Table 5-------------------------------------------*
* Categorical or Dummy Coupledom Styles: Shift from egalitarian to each state
 *From 0 to 1 child and from 1 to higher
		
  *2.1. Different shifts between coupledom styles:
		codebook cptypo_all
		capture drop cp_dum cp_nontra
		recode cptypo_all 1/2=1 3/4=0 5=., gen(cp_dum)	//ega/least tradi to more/most traditional!
		
		recode cptypo_all 1=1 2=. 3=0 4/5=., gen(cp_tra) //ega to tradi
		recode cptypo_all 1=. 2=1 3=0 4/5=., gen(cp_stra) //ega to semi-trad
		recode cptypo_all 1/2=. 3=0 4=1 5=., gen(cp_nontra)	//ega to non-tra
		recode cptypo_all 1/2=. 3=0 4=. 5=1, gen(cp_prec) //ega to precarious
		ta cptypo_all cp_dum, m
		xttab cp_dum
		
			
	*samples changed in cp_dum
		bysort cpid (wave): egen cp_dummax=max(cp_dum)
		bysort cpid (wave): egen cp_dummin=min(cp_dum)
		order cpid wave cp_dum*
		gen cp_dumdiff=[cp_dummax~=cp_dummin]
	    xtdes if cp_dumdiff==1 
/*		
 *FE Sample statistics:
	xttab cp_dum
	ta lcatypo_new if cp_dumdiff==1 
	ta lcatypo_new period3_n if cp_dumdiff==1 , col nof
	gen parentdnew=[nchild>0]
	ta parentdnew if cp_dumdiff==1 
	ta parentdnew period3_n  if cp_dumdiff==1 , col nof
	sum nchild if cp_dumdiff==1 
	sum chagemin if cp_dumdiff==1 
	sum age if cp_dumdiff==1 
	sum sp_age if cp_dumdiff==1 
	ta cohab  if cp_dumdiff==1 
	table period3_n if cp_dumdiff==1, c(mean nchild mean chagemin mean par_dur mean age mean sp_age)
    //In later periods, more children, longer duration, older couples
*/		
*************************************************************
*Models: 1. fe; 2. fe interaction
*************************************************************	
	set seed 339487731 
	set more off	
	eststo clear
		xtlogit  cp_dum	///
									i.nchild3c i.period3_n   /*i.chagemin_c*/  ///
									cohab par_dur ///
									age agesq sp_age sp_agesq  ///
									,  fe 
									
		
		eststo fe1, ti ("Dum2_fe"): clogit  cp_dum	///
									i.nchild3c i.period3_n   /*i.chagemin_c*/  ///
									cohab par_dur ///
									age agesq sp_age sp_agesq  ///
									,  group(cpid) vce(robust)  
		
	
		eststo m1, ti ("Dum2_fe_int"): clogit cp_dum 	///
									i.nchild3c i.period3_n ///
									ch1p2 ch2p2 ch1p3 ch2p3 ///													
									/*i.chagemin_c*/ cohab par_dur  ///
									age agesq sp_age sp_agesq  ///
									, group(cpid) vce(robust) 
									
	//those who are married in later periods have been very traditional already!									
		
	  esttab using "$Output\2019.equity8_Model_all.csv", replace nonum not nodep mti r2 ar2  ///
			starlevels(+ 0.1 * 0.05 ** 0.01 *** 0.001) b(%9.3f) se ///
			ti("The Effect of Child Number on Couple Type (Egal/Non-tradi to Semi/Tradi)") ///
			la addnotes("fixed effect: binomial logistic regressions,not weighted")
			
			
*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX	
 **Hausman test for re and fe:	
*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
			eststo fe1: xtlogit  cp_dum	///
									i.nchild3c i.period3_n   /*i.chagemin_c*/  ///
									cohab par_dur ///
									age agesq sp_age sp_agesq  ///
									,  fe 
									
		   eststo re1: xtlogit  cp_dum	///
									i.nchild3c i.period3_n   /*i.chagemin_c*/  ///
									cohab   par_dur  ///
									age agesq  sp_age sp_agesq  ///
									i.edu3c i.sp_edu3c    ///
									i.new_hlstat i.sp_new_hlstat ///
									i.x_race religion_dum i.country ,re    									
			hausman fe1 re1 
			//re slightly overestimate the effect of children , cohabitation
		
*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX									 
*--------------------Graph--------------------*
*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX		
	*Key variables of interest-number of children:
	*Not including age-average effect of nchild, without restricting it to be children aged 0
	set seed 339487731 
	set more off	
	eststo clear
	
	
		eststo m1: clogit cp_dum 	///
									i.nchild3c i.period3_n ///
									ch1p2 ch2p2 ch1p3 ch2p3 ///													
									/*i.chagemin_c*/ cohab par_dur  ///
									age agesq sp_age sp_agesq , group(cpid) vce(robust) 
									
		eststo m2: clogit cp_dum 	///
									i.nchild3c i.period3_n ///
									ch1p1 ch2p1 ch1p3 ch2p3 ///													
									cohab par_dur   ///
									age agesq sp_age sp_agesq, group(cpid) vce(robust) 
									
		eststo m3: clogit cp_dum 	///
									i.nchild3c i.period3_n ///
									ch1p2 ch2p2 ch1p1 ch2p1  ///													
									cohab par_dur   ///
									age agesq sp_age sp_agesq, group(cpid) vce(robust) 
	
		*set scheme s1mono 
		 
		ta nchild3c
		la def child3cgraph 1 "1 vs. 0 child" 2 ">=2 children vs. 0 child"
		la val nchild3c child3cgraph
		 set scheme s2color
	
		coefplot (m1, eform  keep(*nchild3c) msymbol(D)  label(1991–2000)) ///
		(m2, eform  keep(*nchild3c) pstyle(p2dot) msymbol(Dh) label(2001–2008)) ///
		(m3, eform  keep(*nchild3c) pstyle(p10) msymbol(S) label(2009–2017) ), ///
		 xline(1) xscale(range(0 60)) xlabel(0 (10)120)  ///
		 xtitle ("Odds of moving to a gender traditional division of labor type") ///
		 ciopts(lwidth(*2) lcolor(*.8)) graphregion(color(white)) bgcolor(white)

		//note:the std. error for the coefficient for period 1 actually is similar to those in other periods
		//but the huge odds ratio makes it much larger then...
 
 
 *2. Appendix: The Shift from Egalitarian All Other Coupledom style:
	    ta lcatypo cp_tra, m
		ta lcatypo cp_stra, m
		ta lcatypo cp_nontra, m
		ta lcatypo cp_prec, m
		
		xttab cp_dum 
		xttab cp_tra
		xttab cp_stra
		xttab cp_nontra
		xttab cp_prec
		
		set seed 339487731 
		set more off	
		eststo clear
		
		eststo, ti ("tra_fe"): clogit  cp_tra	///
									i.nchild3c i.period3_n   /*i.chagemin_c*/  ///
									cohab par_dur   ///
									age agesq sp_age sp_agesq, group(cpid) vce(robust)
		
		eststo, ti ("tra_fe_int"): clogit cp_tra 	///
									i.nchild3c i.period3_n ///
									ch1p2 ch2p2  ch1p3 ch2p3 ///													
									 cohab par_dur  ///
									age agesq sp_age sp_agesq , group(cpid) vce(robust)
									 
		eststo, ti ("stra_fe"): clogit  cp_stra	///
									i.nchild3c i.period3_n   ///
									cohab par_dur  ///
									age agesq sp_age sp_agesq  , group(cpid) vce(robust)
		
		eststo, ti ("stra_fe_int"): clogit cp_stra 	///
									i.nchild3c i.period3_n ///
									ch1p2 ch2p2  ch1p3 ch2p3 ///												
									 cohab par_dur   ///
									age agesq sp_age sp_agesq   , group(cpid) vce(robust)
									 
		eststo, ti ("nontra_fe"): clogit  cp_nontra	///
									i.nchild3c i.period3_n    ///
									cohab par_dur   ///
									age agesq sp_age sp_agesq   , group(cpid) vce(robust)
		//NO change
		eststo, ti ("nontra_fe_int"): clogit cp_nontra 	///
									i.nchild3c i.period3_n ///
									ch1p2 ch2p2  ch1p3 ch2p3 ///												
									 cohab par_dur   ///
									age agesq sp_age sp_agesq    , group(cpid) vce(robust)
									 
		eststo, ti ("prec_fe"): clogit  cp_prec	///
									i.nchild3c i.period3_n     ///
									cohab par_dur ///
									age agesq sp_age sp_agesq   , group(cpid) vce(robust)
		
		eststo, ti ("prec_fe_int"): clogit cp_prec 	///
									i.nchild3c i.period3_n ///
									ch1p2 ch2p2  ch1p3 ch2p3 ///												
									 cohab par_dur  ///
									age agesq sp_age sp_agesq   , group(cpid) vce(robust)
		
	  esttab using "$Output\2019.equity8_Model_toall.csv", replace nonum not nodep mti r2 ar2  ///
			starlevels(+ 0.1 * 0.05 ** 0.01 *** 0.001) b(%9.3f) se ///
			ti("The Effect of Child Number on Couple Type (Egal/Non-tradi to Semi/Tradi)") ///
			la addnotes("fixed effect: binomial logistic regressions,not weighted")
		
